fluid_progress_indicator library

Classes

FluidProgressIndicator
A custom fluid progress indicator widget with animated wave effects.
IndicatorBackgroundConfig
Configuration class for customizing the background appearance of a progress indicator.

Typedefs

HeightAnimatedChildBuilder = Widget Function(BuildContext context, double value)
A typedef representing a builder function for animating a child widget's height.